# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_details import TargetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoringTargetDetails(TargetDetails):
    """
    The metric and metric namespace used for the Monitoring target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoringTargetDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.MonitoringTargetDetails.kind` attribute
        of this class is ``monitoring`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this MonitoringTargetDetails.
            Allowed values for this property are: "functions", "loggingAnalytics", "monitoring", "notifications", "objectStorage", "streaming"
        :type kind: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MonitoringTargetDetails.
        :type compartment_id: str

        :param metric_namespace:
            The value to assign to the metric_namespace property of this MonitoringTargetDetails.
        :type metric_namespace: str

        :param metric:
            The value to assign to the metric property of this MonitoringTargetDetails.
        :type metric: str

        """
        self.swagger_types = {
            'kind': 'str',
            'compartment_id': 'str',
            'metric_namespace': 'str',
            'metric': 'str'
        }

        self.attribute_map = {
            'kind': 'kind',
            'compartment_id': 'compartmentId',
            'metric_namespace': 'metricNamespace',
            'metric': 'metric'
        }

        self._kind = None
        self._compartment_id = None
        self._metric_namespace = None
        self._metric = None
        self._kind = 'monitoring'

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MonitoringTargetDetails.
        The `OCID`__ of the compartment containing the metric.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this MonitoringTargetDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MonitoringTargetDetails.
        The `OCID`__ of the compartment containing the metric.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this MonitoringTargetDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def metric_namespace(self):
        """
        **[Required]** Gets the metric_namespace of this MonitoringTargetDetails.
        The namespace of the metric.

        Example: `oci_computeagent`


        :return: The metric_namespace of this MonitoringTargetDetails.
        :rtype: str
        """
        return self._metric_namespace

    @metric_namespace.setter
    def metric_namespace(self, metric_namespace):
        """
        Sets the metric_namespace of this MonitoringTargetDetails.
        The namespace of the metric.

        Example: `oci_computeagent`


        :param metric_namespace: The metric_namespace of this MonitoringTargetDetails.
        :type: str
        """
        self._metric_namespace = metric_namespace

    @property
    def metric(self):
        """
        **[Required]** Gets the metric of this MonitoringTargetDetails.
        The name of the metric.

        Example: `CpuUtilization`


        :return: The metric of this MonitoringTargetDetails.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this MonitoringTargetDetails.
        The name of the metric.

        Example: `CpuUtilization`


        :param metric: The metric of this MonitoringTargetDetails.
        :type: str
        """
        self._metric = metric

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsMetaSourceType(object):
    """
    LogAnalyticsMetaSourceType
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsMetaSourceType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param built_in_parser_name:
            The value to assign to the built_in_parser_name property of this LogAnalyticsMetaSourceType.
        :type built_in_parser_name: str

        :param description:
            The value to assign to the description property of this LogAnalyticsMetaSourceType.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsMetaSourceType.
        :type display_name: str

        :param entity_display_name:
            The value to assign to the entity_display_name property of this LogAnalyticsMetaSourceType.
        :type entity_display_name: str

        :param entity_name:
            The value to assign to the entity_name property of this LogAnalyticsMetaSourceType.
        :type entity_name: str

        :param name:
            The value to assign to the name property of this LogAnalyticsMetaSourceType.
        :type name: str

        :param maximum_exclude_pattern:
            The value to assign to the maximum_exclude_pattern property of this LogAnalyticsMetaSourceType.
        :type maximum_exclude_pattern: int

        :param maximum_include_pattern:
            The value to assign to the maximum_include_pattern property of this LogAnalyticsMetaSourceType.
        :type maximum_include_pattern: int

        """
        self.swagger_types = {
            'built_in_parser_name': 'str',
            'description': 'str',
            'display_name': 'str',
            'entity_display_name': 'str',
            'entity_name': 'str',
            'name': 'str',
            'maximum_exclude_pattern': 'int',
            'maximum_include_pattern': 'int'
        }

        self.attribute_map = {
            'built_in_parser_name': 'builtInParserName',
            'description': 'description',
            'display_name': 'displayName',
            'entity_display_name': 'entityDisplayName',
            'entity_name': 'entityName',
            'name': 'name',
            'maximum_exclude_pattern': 'maximumExcludePattern',
            'maximum_include_pattern': 'maximumIncludePattern'
        }

        self._built_in_parser_name = None
        self._description = None
        self._display_name = None
        self._entity_display_name = None
        self._entity_name = None
        self._name = None
        self._maximum_exclude_pattern = None
        self._maximum_include_pattern = None

    @property
    def built_in_parser_name(self):
        """
        Gets the built_in_parser_name of this LogAnalyticsMetaSourceType.
        The built in parser name.


        :return: The built_in_parser_name of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._built_in_parser_name

    @built_in_parser_name.setter
    def built_in_parser_name(self, built_in_parser_name):
        """
        Sets the built_in_parser_name of this LogAnalyticsMetaSourceType.
        The built in parser name.


        :param built_in_parser_name: The built_in_parser_name of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._built_in_parser_name = built_in_parser_name

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsMetaSourceType.
        The source type description.


        :return: The description of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsMetaSourceType.
        The source type description.


        :param description: The description of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsMetaSourceType.
        The source type display name.


        :return: The display_name of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsMetaSourceType.
        The source type display name.


        :param display_name: The display_name of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._display_name = display_name

    @property
    def entity_display_name(self):
        """
        Gets the entity_display_name of this LogAnalyticsMetaSourceType.
        The entity display name.


        :return: The entity_display_name of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._entity_display_name

    @entity_display_name.setter
    def entity_display_name(self, entity_display_name):
        """
        Sets the entity_display_name of this LogAnalyticsMetaSourceType.
        The entity display name.


        :param entity_display_name: The entity_display_name of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._entity_display_name = entity_display_name

    @property
    def entity_name(self):
        """
        Gets the entity_name of this LogAnalyticsMetaSourceType.
        The entity internal name.


        :return: The entity_name of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this LogAnalyticsMetaSourceType.
        The entity internal name.


        :param entity_name: The entity_name of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsMetaSourceType.
        The source type name.


        :return: The name of this LogAnalyticsMetaSourceType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsMetaSourceType.
        The source type name.


        :param name: The name of this LogAnalyticsMetaSourceType.
        :type: str
        """
        self._name = name

    @property
    def maximum_exclude_pattern(self):
        """
        Gets the maximum_exclude_pattern of this LogAnalyticsMetaSourceType.
        The maximum exclude pattern.


        :return: The maximum_exclude_pattern of this LogAnalyticsMetaSourceType.
        :rtype: int
        """
        return self._maximum_exclude_pattern

    @maximum_exclude_pattern.setter
    def maximum_exclude_pattern(self, maximum_exclude_pattern):
        """
        Sets the maximum_exclude_pattern of this LogAnalyticsMetaSourceType.
        The maximum exclude pattern.


        :param maximum_exclude_pattern: The maximum_exclude_pattern of this LogAnalyticsMetaSourceType.
        :type: int
        """
        self._maximum_exclude_pattern = maximum_exclude_pattern

    @property
    def maximum_include_pattern(self):
        """
        Gets the maximum_include_pattern of this LogAnalyticsMetaSourceType.
        The maximum include pattern.


        :return: The maximum_include_pattern of this LogAnalyticsMetaSourceType.
        :rtype: int
        """
        return self._maximum_include_pattern

    @maximum_include_pattern.setter
    def maximum_include_pattern(self, maximum_include_pattern):
        """
        Sets the maximum_include_pattern of this LogAnalyticsMetaSourceType.
        The maximum include pattern.


        :param maximum_include_pattern: The maximum_include_pattern of this LogAnalyticsMetaSourceType.
        :type: int
        """
        self._maximum_include_pattern = maximum_include_pattern

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRunDetails(object):
    """
    The create run details. The following properties are optional and override the default values
    set in the associated application:
    - applicationId
    - archiveUri
    - arguments
    - configuration
    - definedTags
    - displayName
    - driverShape
    - execute
    - executorShape
    - freeformTags
    - logsBucketUri
    - metastoreId
    - numExecutors
    - parameters
    - sparkVersion
    - warehouseBucketUri
    It is expected that either the applicationId or the execute parameter is specified; but not both.
    If both or none are set, a Bad Request (HTTP 400) status will be sent as the response.
    If an appicationId is not specified, then a value for the execute parameter is expected.
    Using data parsed from the value, a new application will be created and assicated with the new run.
    See information on the execute parameter for details on the format of this parameter.

    The optional parameter spark version can only be specified when using the execute parameter.  If it
    is not specified when using the execute parameter, the latest version will be used as default.
    If the execute parameter is not used, the spark version will be taken from the associated application.

    If displayName is not specified, it will be derived from the displayName of associated application or
    set by API using fileUri's application file name.
    Once a run is created, its properties (except for definedTags and freeformTags) cannot be changed.
    If the parent application's properties (including definedTags and freeformTags) are updated,
    the corresponding properties of the run will not update.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRunDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param application_id:
            The value to assign to the application_id property of this CreateRunDetails.
        :type application_id: str

        :param archive_uri:
            The value to assign to the archive_uri property of this CreateRunDetails.
        :type archive_uri: str

        :param arguments:
            The value to assign to the arguments property of this CreateRunDetails.
        :type arguments: list[str]

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateRunDetails.
        :type compartment_id: str

        :param configuration:
            The value to assign to the configuration property of this CreateRunDetails.
        :type configuration: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateRunDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateRunDetails.
        :type display_name: str

        :param driver_shape:
            The value to assign to the driver_shape property of this CreateRunDetails.
        :type driver_shape: str

        :param execute:
            The value to assign to the execute property of this CreateRunDetails.
        :type execute: str

        :param executor_shape:
            The value to assign to the executor_shape property of this CreateRunDetails.
        :type executor_shape: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateRunDetails.
        :type freeform_tags: dict(str, str)

        :param logs_bucket_uri:
            The value to assign to the logs_bucket_uri property of this CreateRunDetails.
        :type logs_bucket_uri: str

        :param metastore_id:
            The value to assign to the metastore_id property of this CreateRunDetails.
        :type metastore_id: str

        :param num_executors:
            The value to assign to the num_executors property of this CreateRunDetails.
        :type num_executors: int

        :param parameters:
            The value to assign to the parameters property of this CreateRunDetails.
        :type parameters: list[oci.data_flow.models.ApplicationParameter]

        :param spark_version:
            The value to assign to the spark_version property of this CreateRunDetails.
        :type spark_version: str

        :param warehouse_bucket_uri:
            The value to assign to the warehouse_bucket_uri property of this CreateRunDetails.
        :type warehouse_bucket_uri: str

        """
        self.swagger_types = {
            'application_id': 'str',
            'archive_uri': 'str',
            'arguments': 'list[str]',
            'compartment_id': 'str',
            'configuration': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'driver_shape': 'str',
            'execute': 'str',
            'executor_shape': 'str',
            'freeform_tags': 'dict(str, str)',
            'logs_bucket_uri': 'str',
            'metastore_id': 'str',
            'num_executors': 'int',
            'parameters': 'list[ApplicationParameter]',
            'spark_version': 'str',
            'warehouse_bucket_uri': 'str'
        }

        self.attribute_map = {
            'application_id': 'applicationId',
            'archive_uri': 'archiveUri',
            'arguments': 'arguments',
            'compartment_id': 'compartmentId',
            'configuration': 'configuration',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'driver_shape': 'driverShape',
            'execute': 'execute',
            'executor_shape': 'executorShape',
            'freeform_tags': 'freeformTags',
            'logs_bucket_uri': 'logsBucketUri',
            'metastore_id': 'metastoreId',
            'num_executors': 'numExecutors',
            'parameters': 'parameters',
            'spark_version': 'sparkVersion',
            'warehouse_bucket_uri': 'warehouseBucketUri'
        }

        self._application_id = None
        self._archive_uri = None
        self._arguments = None
        self._compartment_id = None
        self._configuration = None
        self._defined_tags = None
        self._display_name = None
        self._driver_shape = None
        self._execute = None
        self._executor_shape = None
        self._freeform_tags = None
        self._logs_bucket_uri = None
        self._metastore_id = None
        self._num_executors = None
        self._parameters = None
        self._spark_version = None
        self._warehouse_bucket_uri = None

    @property
    def application_id(self):
        """
        Gets the application_id of this CreateRunDetails.
        The OCID of the associated application. If this value is set, then no value for the execute parameter is required. If this value is not set, then a value for the execute parameter is required, and a new application is created and associated with the new run.


        :return: The application_id of this CreateRunDetails.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this CreateRunDetails.
        The OCID of the associated application. If this value is set, then no value for the execute parameter is required. If this value is not set, then a value for the execute parameter is required, and a new application is created and associated with the new run.


        :param application_id: The application_id of this CreateRunDetails.
        :type: str
        """
        self._application_id = application_id

    @property
    def archive_uri(self):
        """
        Gets the archive_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The archive_uri of this CreateRunDetails.
        :rtype: str
        """
        return self._archive_uri

    @archive_uri.setter
    def archive_uri(self, archive_uri):
        """
        Sets the archive_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param archive_uri: The archive_uri of this CreateRunDetails.
        :type: str
        """
        self._archive_uri = archive_uri

    @property
    def arguments(self):
        """
        Gets the arguments of this CreateRunDetails.
        The arguments passed to the running application as command line arguments.  An argument is
        either a plain text or a placeholder. Placeholders are replaced using values from the parameters
        map.  Each placeholder specified must be represented in the parameters map else the request
        (POST or PUT) will fail with a HTTP 400 status code.  Placeholders are specified as
        `Service Api Spec`, where `name` is the name of the parameter.
        Example:  `[ \"--input\", \"${input_file}\", \"--name\", \"John Doe\" ]`
        If \"input_file\" has a value of \"mydata.xml\", then the value above will be translated to
        `--input mydata.xml --name \"John Doe\"`


        :return: The arguments of this CreateRunDetails.
        :rtype: list[str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this CreateRunDetails.
        The arguments passed to the running application as command line arguments.  An argument is
        either a plain text or a placeholder. Placeholders are replaced using values from the parameters
        map.  Each placeholder specified must be represented in the parameters map else the request
        (POST or PUT) will fail with a HTTP 400 status code.  Placeholders are specified as
        `Service Api Spec`, where `name` is the name of the parameter.
        Example:  `[ \"--input\", \"${input_file}\", \"--name\", \"John Doe\" ]`
        If \"input_file\" has a value of \"mydata.xml\", then the value above will be translated to
        `--input mydata.xml --name \"John Doe\"`


        :param arguments: The arguments of this CreateRunDetails.
        :type: list[str]
        """
        self._arguments = arguments

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateRunDetails.
        The OCID of a compartment.


        :return: The compartment_id of this CreateRunDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateRunDetails.
        The OCID of a compartment.


        :param compartment_id: The compartment_id of this CreateRunDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def configuration(self):
        """
        Gets the configuration of this CreateRunDetails.
        The Spark configuration passed to the running process.
        See https://spark.apache.org/docs/latest/configuration.html#available-properties.
        Example: { \"spark.app.name\" : \"My App Name\", \"spark.shuffle.io.maxRetries\" : \"4\" }
        Note: Not all Spark properties are permitted to be set.  Attempting to set a property that is
        not allowed to be overwritten will cause a 400 status to be returned.


        :return: The configuration of this CreateRunDetails.
        :rtype: dict(str, str)
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """
        Sets the configuration of this CreateRunDetails.
        The Spark configuration passed to the running process.
        See https://spark.apache.org/docs/latest/configuration.html#available-properties.
        Example: { \"spark.app.name\" : \"My App Name\", \"spark.shuffle.io.maxRetries\" : \"4\" }
        Note: Not all Spark properties are permitted to be set.  Attempting to set a property that is
        not allowed to be overwritten will cause a 400 status to be returned.


        :param configuration: The configuration of this CreateRunDetails.
        :type: dict(str, str)
        """
        self._configuration = configuration

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateRunDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateRunDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateRunDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateRunDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateRunDetails.
        A user-friendly name that does not have to be unique. Avoid entering confidential information. If this value is not specified, it will be derived from the associated application's displayName or set by API using fileUri's application file name.


        :return: The display_name of this CreateRunDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateRunDetails.
        A user-friendly name that does not have to be unique. Avoid entering confidential information. If this value is not specified, it will be derived from the associated application's displayName or set by API using fileUri's application file name.


        :param display_name: The display_name of this CreateRunDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def driver_shape(self):
        """
        Gets the driver_shape of this CreateRunDetails.
        The VM shape for the driver. Sets the driver cores and memory.


        :return: The driver_shape of this CreateRunDetails.
        :rtype: str
        """
        return self._driver_shape

    @driver_shape.setter
    def driver_shape(self, driver_shape):
        """
        Sets the driver_shape of this CreateRunDetails.
        The VM shape for the driver. Sets the driver cores and memory.


        :param driver_shape: The driver_shape of this CreateRunDetails.
        :type: str
        """
        self._driver_shape = driver_shape

    @property
    def execute(self):
        """
        Gets the execute of this CreateRunDetails.
        The input used for spark-submit command. For more details see https://spark.apache.org/docs/latest/submitting-applications.html#launching-applications-with-spark-submit.
        Supported options include ``--class``, ``--file``, ``--jars``, ``--conf``, ``--py-files``, and main application file with arguments.
        Example: ``--jars oci://path/to/a.jar,oci://path/to/b.jar --files oci://path/to/a.json,oci://path/to/b.csv --py-files oci://path/to/a.py,oci://path/to/b.py --conf spark.sql.crossJoin.enabled=true --class org.apache.spark.examples.SparkPi oci://path/to/main.jar 10``
        Note: If execute is specified together with applicationId, className, configuration, fileUri, language, arguments, parameters during application create/update, or run create/submit,
        Data Flow service will use derived information from execute input only.


        :return: The execute of this CreateRunDetails.
        :rtype: str
        """
        return self._execute

    @execute.setter
    def execute(self, execute):
        """
        Sets the execute of this CreateRunDetails.
        The input used for spark-submit command. For more details see https://spark.apache.org/docs/latest/submitting-applications.html#launching-applications-with-spark-submit.
        Supported options include ``--class``, ``--file``, ``--jars``, ``--conf``, ``--py-files``, and main application file with arguments.
        Example: ``--jars oci://path/to/a.jar,oci://path/to/b.jar --files oci://path/to/a.json,oci://path/to/b.csv --py-files oci://path/to/a.py,oci://path/to/b.py --conf spark.sql.crossJoin.enabled=true --class org.apache.spark.examples.SparkPi oci://path/to/main.jar 10``
        Note: If execute is specified together with applicationId, className, configuration, fileUri, language, arguments, parameters during application create/update, or run create/submit,
        Data Flow service will use derived information from execute input only.


        :param execute: The execute of this CreateRunDetails.
        :type: str
        """
        self._execute = execute

    @property
    def executor_shape(self):
        """
        Gets the executor_shape of this CreateRunDetails.
        The VM shape for the executors. Sets the executor cores and memory.


        :return: The executor_shape of this CreateRunDetails.
        :rtype: str
        """
        return self._executor_shape

    @executor_shape.setter
    def executor_shape(self, executor_shape):
        """
        Sets the executor_shape of this CreateRunDetails.
        The VM shape for the executors. Sets the executor cores and memory.


        :param executor_shape: The executor_shape of this CreateRunDetails.
        :type: str
        """
        self._executor_shape = executor_shape

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateRunDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateRunDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateRunDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateRunDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def logs_bucket_uri(self):
        """
        Gets the logs_bucket_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The logs_bucket_uri of this CreateRunDetails.
        :rtype: str
        """
        return self._logs_bucket_uri

    @logs_bucket_uri.setter
    def logs_bucket_uri(self, logs_bucket_uri):
        """
        Sets the logs_bucket_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param logs_bucket_uri: The logs_bucket_uri of this CreateRunDetails.
        :type: str
        """
        self._logs_bucket_uri = logs_bucket_uri

    @property
    def metastore_id(self):
        """
        Gets the metastore_id of this CreateRunDetails.
        The OCID of OCI Hive Metastore.


        :return: The metastore_id of this CreateRunDetails.
        :rtype: str
        """
        return self._metastore_id

    @metastore_id.setter
    def metastore_id(self, metastore_id):
        """
        Sets the metastore_id of this CreateRunDetails.
        The OCID of OCI Hive Metastore.


        :param metastore_id: The metastore_id of this CreateRunDetails.
        :type: str
        """
        self._metastore_id = metastore_id

    @property
    def num_executors(self):
        """
        Gets the num_executors of this CreateRunDetails.
        The number of executor VMs requested.


        :return: The num_executors of this CreateRunDetails.
        :rtype: int
        """
        return self._num_executors

    @num_executors.setter
    def num_executors(self, num_executors):
        """
        Sets the num_executors of this CreateRunDetails.
        The number of executor VMs requested.


        :param num_executors: The num_executors of this CreateRunDetails.
        :type: int
        """
        self._num_executors = num_executors

    @property
    def parameters(self):
        """
        Gets the parameters of this CreateRunDetails.
        An array of name/value pairs used to fill placeholders found in properties like
        `Application.arguments`.  The name must be a string of one or more word characters
        (a-z, A-Z, 0-9, _).  The value can be a string of 0 or more characters of any kind.
        Example:  [ { name: \"iterations\", value: \"10\"}, { name: \"input_file\", value: \"mydata.xml\" }, { name: \"variable_x\", value: \"${x}\"} ]


        :return: The parameters of this CreateRunDetails.
        :rtype: list[oci.data_flow.models.ApplicationParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this CreateRunDetails.
        An array of name/value pairs used to fill placeholders found in properties like
        `Application.arguments`.  The name must be a string of one or more word characters
        (a-z, A-Z, 0-9, _).  The value can be a string of 0 or more characters of any kind.
        Example:  [ { name: \"iterations\", value: \"10\"}, { name: \"input_file\", value: \"mydata.xml\" }, { name: \"variable_x\", value: \"${x}\"} ]


        :param parameters: The parameters of this CreateRunDetails.
        :type: list[oci.data_flow.models.ApplicationParameter]
        """
        self._parameters = parameters

    @property
    def spark_version(self):
        """
        Gets the spark_version of this CreateRunDetails.
        The Spark version utilized to run the application. This value may be set if applicationId is not since the Spark version will be taken from the associated application.


        :return: The spark_version of this CreateRunDetails.
        :rtype: str
        """
        return self._spark_version

    @spark_version.setter
    def spark_version(self, spark_version):
        """
        Sets the spark_version of this CreateRunDetails.
        The Spark version utilized to run the application. This value may be set if applicationId is not since the Spark version will be taken from the associated application.


        :param spark_version: The spark_version of this CreateRunDetails.
        :type: str
        """
        self._spark_version = spark_version

    @property
    def warehouse_bucket_uri(self):
        """
        Gets the warehouse_bucket_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory
        for BATCH SQL runs.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The warehouse_bucket_uri of this CreateRunDetails.
        :rtype: str
        """
        return self._warehouse_bucket_uri

    @warehouse_bucket_uri.setter
    def warehouse_bucket_uri(self, warehouse_bucket_uri):
        """
        Sets the warehouse_bucket_uri of this CreateRunDetails.
        An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory
        for BATCH SQL runs.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param warehouse_bucket_uri: The warehouse_bucket_uri of this CreateRunDetails.
        :type: str
        """
        self._warehouse_bucket_uri = warehouse_bucket_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VolumeBackupPolicyAssignment(object):
    """
    Specifies the volume that the volume backup policy is assigned to.

    For more information about Oracle defined backup policies and custom backup policies,
    see `Policy-Based Backups`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VolumeBackupPolicyAssignment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param asset_id:
            The value to assign to the asset_id property of this VolumeBackupPolicyAssignment.
        :type asset_id: str

        :param id:
            The value to assign to the id property of this VolumeBackupPolicyAssignment.
        :type id: str

        :param policy_id:
            The value to assign to the policy_id property of this VolumeBackupPolicyAssignment.
        :type policy_id: str

        :param time_created:
            The value to assign to the time_created property of this VolumeBackupPolicyAssignment.
        :type time_created: datetime

        """
        self.swagger_types = {
            'asset_id': 'str',
            'id': 'str',
            'policy_id': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'asset_id': 'assetId',
            'id': 'id',
            'policy_id': 'policyId',
            'time_created': 'timeCreated'
        }

        self._asset_id = None
        self._id = None
        self._policy_id = None
        self._time_created = None

    @property
    def asset_id(self):
        """
        **[Required]** Gets the asset_id of this VolumeBackupPolicyAssignment.
        The OCID of the volume the policy has been assigned to.


        :return: The asset_id of this VolumeBackupPolicyAssignment.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """
        Sets the asset_id of this VolumeBackupPolicyAssignment.
        The OCID of the volume the policy has been assigned to.


        :param asset_id: The asset_id of this VolumeBackupPolicyAssignment.
        :type: str
        """
        self._asset_id = asset_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VolumeBackupPolicyAssignment.
        The OCID of the volume backup policy assignment.


        :return: The id of this VolumeBackupPolicyAssignment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VolumeBackupPolicyAssignment.
        The OCID of the volume backup policy assignment.


        :param id: The id of this VolumeBackupPolicyAssignment.
        :type: str
        """
        self._id = id

    @property
    def policy_id(self):
        """
        **[Required]** Gets the policy_id of this VolumeBackupPolicyAssignment.
        The OCID of the volume backup policy that has been assigned to the volume.


        :return: The policy_id of this VolumeBackupPolicyAssignment.
        :rtype: str
        """
        return self._policy_id

    @policy_id.setter
    def policy_id(self, policy_id):
        """
        Sets the policy_id of this VolumeBackupPolicyAssignment.
        The OCID of the volume backup policy that has been assigned to the volume.


        :param policy_id: The policy_id of this VolumeBackupPolicyAssignment.
        :type: str
        """
        self._policy_id = policy_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this VolumeBackupPolicyAssignment.
        The date and time the volume backup policy was assigned to the volume. The format is
        defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this VolumeBackupPolicyAssignment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VolumeBackupPolicyAssignment.
        The date and time the volume backup policy was assigned to the volume. The format is
        defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this VolumeBackupPolicyAssignment.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VersionSummary(object):
    """
    A summary of the supported MySQL Versions families, and a list of their supported minor versions.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VersionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version_family:
            The value to assign to the version_family property of this VersionSummary.
        :type version_family: str

        :param versions:
            The value to assign to the versions property of this VersionSummary.
        :type versions: list[oci.mysql.models.Version]

        """
        self.swagger_types = {
            'version_family': 'str',
            'versions': 'list[Version]'
        }

        self.attribute_map = {
            'version_family': 'versionFamily',
            'versions': 'versions'
        }

        self._version_family = None
        self._versions = None

    @property
    def version_family(self):
        """
        Gets the version_family of this VersionSummary.
        A descriptive summary of a group of versions.


        :return: The version_family of this VersionSummary.
        :rtype: str
        """
        return self._version_family

    @version_family.setter
    def version_family(self, version_family):
        """
        Sets the version_family of this VersionSummary.
        A descriptive summary of a group of versions.


        :param version_family: The version_family of this VersionSummary.
        :type: str
        """
        self._version_family = version_family

    @property
    def versions(self):
        """
        **[Required]** Gets the versions of this VersionSummary.
        The list of supported MySQL Versions.


        :return: The versions of this VersionSummary.
        :rtype: list[oci.mysql.models.Version]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """
        Sets the versions of this VersionSummary.
        The list of supported MySQL Versions.


        :param versions: The versions of this VersionSummary.
        :type: list[oci.mysql.models.Version]
        """
        self._versions = versions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Time(object):
    """
    A model to hold time in hour:minute:second format.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Time object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hour:
            The value to assign to the hour property of this Time.
        :type hour: int

        :param minute:
            The value to assign to the minute property of this Time.
        :type minute: int

        :param second:
            The value to assign to the second property of this Time.
        :type second: int

        """
        self.swagger_types = {
            'hour': 'int',
            'minute': 'int',
            'second': 'int'
        }

        self.attribute_map = {
            'hour': 'hour',
            'minute': 'minute',
            'second': 'second'
        }

        self._hour = None
        self._minute = None
        self._second = None

    @property
    def hour(self):
        """
        Gets the hour of this Time.
        The hour value.


        :return: The hour of this Time.
        :rtype: int
        """
        return self._hour

    @hour.setter
    def hour(self, hour):
        """
        Sets the hour of this Time.
        The hour value.


        :param hour: The hour of this Time.
        :type: int
        """
        self._hour = hour

    @property
    def minute(self):
        """
        Gets the minute of this Time.
        The minute value.


        :return: The minute of this Time.
        :rtype: int
        """
        return self._minute

    @minute.setter
    def minute(self, minute):
        """
        Sets the minute of this Time.
        The minute value.


        :param minute: The minute of this Time.
        :type: int
        """
        self._minute = minute

    @property
    def second(self):
        """
        Gets the second of this Time.
        The second value.


        :return: The second of this Time.
        :rtype: int
        """
        return self._second

    @second.setter
    def second(self, second):
        """
        Sets the second of this Time.
        The second value.


        :param second: The second of this Time.
        :type: int
        """
        self._second = second

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MigrationPhaseSummary(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Migration Phase Summary of details.
    """

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_TGT"
    NAME_ODMS_VALIDATE_TGT = "ODMS_VALIDATE_TGT"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_SRC"
    NAME_ODMS_VALIDATE_SRC = "ODMS_VALIDATE_SRC"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_GG_HUB"
    NAME_ODMS_VALIDATE_GG_HUB = "ODMS_VALIDATE_GG_HUB"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_DATAPUMP_SETTINGS"
    NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS = "ODMS_VALIDATE_DATAPUMP_SETTINGS"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC"
    NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC = "ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT"
    NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT = "ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_VALIDATE"
    NAME_ODMS_VALIDATE = "ODMS_VALIDATE"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_PREPARE"
    NAME_ODMS_PREPARE = "ODMS_PREPARE"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_INITIAL_LOAD_EXPORT"
    NAME_ODMS_INITIAL_LOAD_EXPORT = "ODMS_INITIAL_LOAD_EXPORT"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_DATA_UPLOAD"
    NAME_ODMS_DATA_UPLOAD = "ODMS_DATA_UPLOAD"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_INITIAL_LOAD_IMPORT"
    NAME_ODMS_INITIAL_LOAD_IMPORT = "ODMS_INITIAL_LOAD_IMPORT"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_POST_INITIAL_LOAD"
    NAME_ODMS_POST_INITIAL_LOAD = "ODMS_POST_INITIAL_LOAD"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_PREPARE_REPLICATION_TARGET"
    NAME_ODMS_PREPARE_REPLICATION_TARGET = "ODMS_PREPARE_REPLICATION_TARGET"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_MONITOR_REPLICATION_LAG"
    NAME_ODMS_MONITOR_REPLICATION_LAG = "ODMS_MONITOR_REPLICATION_LAG"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_SWITCHOVER"
    NAME_ODMS_SWITCHOVER = "ODMS_SWITCHOVER"

    #: A constant which can be used with the name property of a MigrationPhaseSummary.
    #: This constant has a value of "ODMS_CLEANUP"
    NAME_ODMS_CLEANUP = "ODMS_CLEANUP"

    #: A constant which can be used with the recommended_action property of a MigrationPhaseSummary.
    #: This constant has a value of "WAIT"
    RECOMMENDED_ACTION_WAIT = "WAIT"

    def __init__(self, **kwargs):
        """
        Initializes a new MigrationPhaseSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this MigrationPhaseSummary.
            Allowed values for this property are: "ODMS_VALIDATE_TGT", "ODMS_VALIDATE_SRC", "ODMS_VALIDATE_GG_HUB", "ODMS_VALIDATE_DATAPUMP_SETTINGS", "ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC", "ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT", "ODMS_VALIDATE", "ODMS_PREPARE", "ODMS_INITIAL_LOAD_EXPORT", "ODMS_DATA_UPLOAD", "ODMS_INITIAL_LOAD_IMPORT", "ODMS_POST_INITIAL_LOAD", "ODMS_PREPARE_REPLICATION_TARGET", "ODMS_MONITOR_REPLICATION_LAG", "ODMS_SWITCHOVER", "ODMS_CLEANUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param recommended_action:
            The value to assign to the recommended_action property of this MigrationPhaseSummary.
            Allowed values for this property are: "WAIT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type recommended_action: str

        :param supported_actions:
            The value to assign to the supported_actions property of this MigrationPhaseSummary.
        :type supported_actions: list[oci.database_migration.models.OdmsPhaseActions]

        """
        self.swagger_types = {
            'name': 'str',
            'recommended_action': 'str',
            'supported_actions': 'list[OdmsPhaseActions]'
        }

        self.attribute_map = {
            'name': 'name',
            'recommended_action': 'recommendedAction',
            'supported_actions': 'supportedActions'
        }

        self._name = None
        self._recommended_action = None
        self._supported_actions = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this MigrationPhaseSummary.
        ODMS Job phase name

        Allowed values for this property are: "ODMS_VALIDATE_TGT", "ODMS_VALIDATE_SRC", "ODMS_VALIDATE_GG_HUB", "ODMS_VALIDATE_DATAPUMP_SETTINGS", "ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC", "ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT", "ODMS_VALIDATE", "ODMS_PREPARE", "ODMS_INITIAL_LOAD_EXPORT", "ODMS_DATA_UPLOAD", "ODMS_INITIAL_LOAD_IMPORT", "ODMS_POST_INITIAL_LOAD", "ODMS_PREPARE_REPLICATION_TARGET", "ODMS_MONITOR_REPLICATION_LAG", "ODMS_SWITCHOVER", "ODMS_CLEANUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this MigrationPhaseSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MigrationPhaseSummary.
        ODMS Job phase name


        :param name: The name of this MigrationPhaseSummary.
        :type: str
        """
        allowed_values = ["ODMS_VALIDATE_TGT", "ODMS_VALIDATE_SRC", "ODMS_VALIDATE_GG_HUB", "ODMS_VALIDATE_DATAPUMP_SETTINGS", "ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC", "ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT", "ODMS_VALIDATE", "ODMS_PREPARE", "ODMS_INITIAL_LOAD_EXPORT", "ODMS_DATA_UPLOAD", "ODMS_INITIAL_LOAD_IMPORT", "ODMS_POST_INITIAL_LOAD", "ODMS_PREPARE_REPLICATION_TARGET", "ODMS_MONITOR_REPLICATION_LAG", "ODMS_SWITCHOVER", "ODMS_CLEANUP"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    @property
    def recommended_action(self):
        """
        Gets the recommended_action of this MigrationPhaseSummary.
        Action recommended for this phase. If not included in the response, there is no recommended action for the phase.

        Allowed values for this property are: "WAIT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The recommended_action of this MigrationPhaseSummary.
        :rtype: str
        """
        return self._recommended_action

    @recommended_action.setter
    def recommended_action(self, recommended_action):
        """
        Sets the recommended_action of this MigrationPhaseSummary.
        Action recommended for this phase. If not included in the response, there is no recommended action for the phase.


        :param recommended_action: The recommended_action of this MigrationPhaseSummary.
        :type: str
        """
        allowed_values = ["WAIT"]
        if not value_allowed_none_or_none_sentinel(recommended_action, allowed_values):
            recommended_action = 'UNKNOWN_ENUM_VALUE'
        self._recommended_action = recommended_action

    @property
    def supported_actions(self):
        """
        **[Required]** Gets the supported_actions of this MigrationPhaseSummary.
        Array of actions for the corresponding phase. Empty array would indicate there is no supported action for the phase.


        :return: The supported_actions of this MigrationPhaseSummary.
        :rtype: list[oci.database_migration.models.OdmsPhaseActions]
        """
        return self._supported_actions

    @supported_actions.setter
    def supported_actions(self, supported_actions):
        """
        Sets the supported_actions of this MigrationPhaseSummary.
        Array of actions for the corresponding phase. Empty array would indicate there is no supported action for the phase.


        :param supported_actions: The supported_actions of this MigrationPhaseSummary.
        :type: list[oci.database_migration.models.OdmsPhaseActions]
        """
        self._supported_actions = supported_actions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRoutingPolicyDetails(object):
    """
    An ordered list of routing rules.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the condition_language_version property of a CreateRoutingPolicyDetails.
    #: This constant has a value of "V1"
    CONDITION_LANGUAGE_VERSION_V1 = "V1"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRoutingPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateRoutingPolicyDetails.
        :type name: str

        :param condition_language_version:
            The value to assign to the condition_language_version property of this CreateRoutingPolicyDetails.
            Allowed values for this property are: "V1"
        :type condition_language_version: str

        :param rules:
            The value to assign to the rules property of this CreateRoutingPolicyDetails.
        :type rules: list[oci.load_balancer.models.RoutingRule]

        """
        self.swagger_types = {
            'name': 'str',
            'condition_language_version': 'str',
            'rules': 'list[RoutingRule]'
        }

        self.attribute_map = {
            'name': 'name',
            'condition_language_version': 'conditionLanguageVersion',
            'rules': 'rules'
        }

        self._name = None
        self._condition_language_version = None
        self._rules = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateRoutingPolicyDetails.
        The name for this list of routing rules. It must be unique and it cannot be changed. Avoid entering
        confidential information.

        Example: `example_routing_rules`


        :return: The name of this CreateRoutingPolicyDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateRoutingPolicyDetails.
        The name for this list of routing rules. It must be unique and it cannot be changed. Avoid entering
        confidential information.

        Example: `example_routing_rules`


        :param name: The name of this CreateRoutingPolicyDetails.
        :type: str
        """
        self._name = name

    @property
    def condition_language_version(self):
        """
        **[Required]** Gets the condition_language_version of this CreateRoutingPolicyDetails.
        The version of the language in which `condition` of `rules` are composed.

        Allowed values for this property are: "V1"


        :return: The condition_language_version of this CreateRoutingPolicyDetails.
        :rtype: str
        """
        return self._condition_language_version

    @condition_language_version.setter
    def condition_language_version(self, condition_language_version):
        """
        Sets the condition_language_version of this CreateRoutingPolicyDetails.
        The version of the language in which `condition` of `rules` are composed.


        :param condition_language_version: The condition_language_version of this CreateRoutingPolicyDetails.
        :type: str
        """
        allowed_values = ["V1"]
        if not value_allowed_none_or_none_sentinel(condition_language_version, allowed_values):
            raise ValueError(
                "Invalid value for `condition_language_version`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._condition_language_version = condition_language_version

    @property
    def rules(self):
        """
        **[Required]** Gets the rules of this CreateRoutingPolicyDetails.
        The list of routing rules.


        :return: The rules of this CreateRoutingPolicyDetails.
        :rtype: list[oci.load_balancer.models.RoutingRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this CreateRoutingPolicyDetails.
        The list of routing rules.


        :param rules: The rules of this CreateRoutingPolicyDetails.
        :type: list[oci.load_balancer.models.RoutingRule]
        """
        self._rules = rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .item import Item
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TechSupportItem(Item):
    """
    Details about the TechSupportItem object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TechSupportItem object with values from keyword arguments. The default value of the :py:attr:`~oci.cims.models.TechSupportItem.type` attribute
        of this class is ``tech`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param item_key:
            The value to assign to the item_key property of this TechSupportItem.
        :type item_key: str

        :param name:
            The value to assign to the name property of this TechSupportItem.
        :type name: str

        :param type:
            The value to assign to the type property of this TechSupportItem.
        :type type: str

        :param category:
            The value to assign to the category property of this TechSupportItem.
        :type category: oci.cims.models.Category

        :param sub_category:
            The value to assign to the sub_category property of this TechSupportItem.
        :type sub_category: oci.cims.models.SubCategory

        :param issue_type:
            The value to assign to the issue_type property of this TechSupportItem.
        :type issue_type: oci.cims.models.IssueType

        """
        self.swagger_types = {
            'item_key': 'str',
            'name': 'str',
            'type': 'str',
            'category': 'Category',
            'sub_category': 'SubCategory',
            'issue_type': 'IssueType'
        }

        self.attribute_map = {
            'item_key': 'itemKey',
            'name': 'name',
            'type': 'type',
            'category': 'category',
            'sub_category': 'subCategory',
            'issue_type': 'issueType'
        }

        self._item_key = None
        self._name = None
        self._type = None
        self._category = None
        self._sub_category = None
        self._issue_type = None
        self._type = 'tech'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LaunchInstanceAgentConfigDetails(object):
    """
    Configuration options for the Oracle Cloud Agent software running on the instance.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LaunchInstanceAgentConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_monitoring_disabled:
            The value to assign to the is_monitoring_disabled property of this LaunchInstanceAgentConfigDetails.
        :type is_monitoring_disabled: bool

        :param is_management_disabled:
            The value to assign to the is_management_disabled property of this LaunchInstanceAgentConfigDetails.
        :type is_management_disabled: bool

        :param are_all_plugins_disabled:
            The value to assign to the are_all_plugins_disabled property of this LaunchInstanceAgentConfigDetails.
        :type are_all_plugins_disabled: bool

        :param plugins_config:
            The value to assign to the plugins_config property of this LaunchInstanceAgentConfigDetails.
        :type plugins_config: list[oci.core.models.InstanceAgentPluginConfigDetails]

        """
        self.swagger_types = {
            'is_monitoring_disabled': 'bool',
            'is_management_disabled': 'bool',
            'are_all_plugins_disabled': 'bool',
            'plugins_config': 'list[InstanceAgentPluginConfigDetails]'
        }

        self.attribute_map = {
            'is_monitoring_disabled': 'isMonitoringDisabled',
            'is_management_disabled': 'isManagementDisabled',
            'are_all_plugins_disabled': 'areAllPluginsDisabled',
            'plugins_config': 'pluginsConfig'
        }

        self._is_monitoring_disabled = None
        self._is_management_disabled = None
        self._are_all_plugins_disabled = None
        self._plugins_config = None

    @property
    def is_monitoring_disabled(self):
        """
        Gets the is_monitoring_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the
        monitoring plugins. Default value is false (monitoring plugins are enabled).

        These are the monitoring plugins: Compute Instance Monitoring
        and Custom Logs Monitoring.

        The monitoring plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isMonitoringDisabled` is true, all of the monitoring plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isMonitoringDisabled` is false, all of the monitoring plugins are enabled. You
        can optionally disable individual monitoring plugins by providing a value in the `pluginsConfig`
        object.


        :return: The is_monitoring_disabled of this LaunchInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_monitoring_disabled

    @is_monitoring_disabled.setter
    def is_monitoring_disabled(self, is_monitoring_disabled):
        """
        Sets the is_monitoring_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the
        monitoring plugins. Default value is false (monitoring plugins are enabled).

        These are the monitoring plugins: Compute Instance Monitoring
        and Custom Logs Monitoring.

        The monitoring plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isMonitoringDisabled` is true, all of the monitoring plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isMonitoringDisabled` is false, all of the monitoring plugins are enabled. You
        can optionally disable individual monitoring plugins by providing a value in the `pluginsConfig`
        object.


        :param is_monitoring_disabled: The is_monitoring_disabled of this LaunchInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_monitoring_disabled = is_monitoring_disabled

    @property
    def is_management_disabled(self):
        """
        Gets the is_management_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available management plugins.
        Default value is false (management plugins are enabled).

        These are the management plugins: OS Management Service Agent and Compute Instance
        Run Command.

        The management plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isManagementDisabled` is true, all of the management plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isManagementDisabled` is false, all of the management plugins are enabled. You
        can optionally disable individual management plugins by providing a value in the `pluginsConfig`
        object.


        :return: The is_management_disabled of this LaunchInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_management_disabled

    @is_management_disabled.setter
    def is_management_disabled(self, is_management_disabled):
        """
        Sets the is_management_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available management plugins.
        Default value is false (management plugins are enabled).

        These are the management plugins: OS Management Service Agent and Compute Instance
        Run Command.

        The management plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isManagementDisabled` is true, all of the management plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isManagementDisabled` is false, all of the management plugins are enabled. You
        can optionally disable individual management plugins by providing a value in the `pluginsConfig`
        object.


        :param is_management_disabled: The is_management_disabled of this LaunchInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_management_disabled = is_management_disabled

    @property
    def are_all_plugins_disabled(self):
        """
        Gets the are_all_plugins_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available plugins.
        This includes the management and monitoring plugins.

        To get a list of available plugins, use the
        :func:`list_instanceagent_available_plugins`
        operation in the Oracle Cloud Agent API. For more information about the available plugins, see
        `Managing Plugins with Oracle Cloud Agent`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/manage-plugins.htm


        :return: The are_all_plugins_disabled of this LaunchInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._are_all_plugins_disabled

    @are_all_plugins_disabled.setter
    def are_all_plugins_disabled(self, are_all_plugins_disabled):
        """
        Sets the are_all_plugins_disabled of this LaunchInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available plugins.
        This includes the management and monitoring plugins.

        To get a list of available plugins, use the
        :func:`list_instanceagent_available_plugins`
        operation in the Oracle Cloud Agent API. For more information about the available plugins, see
        `Managing Plugins with Oracle Cloud Agent`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/manage-plugins.htm


        :param are_all_plugins_disabled: The are_all_plugins_disabled of this LaunchInstanceAgentConfigDetails.
        :type: bool
        """
        self._are_all_plugins_disabled = are_all_plugins_disabled

    @property
    def plugins_config(self):
        """
        Gets the plugins_config of this LaunchInstanceAgentConfigDetails.
        The configuration of plugins associated with this instance.


        :return: The plugins_config of this LaunchInstanceAgentConfigDetails.
        :rtype: list[oci.core.models.InstanceAgentPluginConfigDetails]
        """
        return self._plugins_config

    @plugins_config.setter
    def plugins_config(self, plugins_config):
        """
        Sets the plugins_config of this LaunchInstanceAgentConfigDetails.
        The configuration of plugins associated with this instance.


        :param plugins_config: The plugins_config of this LaunchInstanceAgentConfigDetails.
        :type: list[oci.core.models.InstanceAgentPluginConfigDetails]
        """
        self._plugins_config = plugins_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfigureAutonomousDatabaseVaultKeyDetails(object):
    """
    Configuration details for the Autonomous Database `vault`__ key.

    __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConfigureAutonomousDatabaseVaultKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kms_key_id:
            The value to assign to the kms_key_id property of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type kms_key_id: str

        :param vault_id:
            The value to assign to the vault_id property of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type vault_id: str

        :param is_using_oracle_managed_keys:
            The value to assign to the is_using_oracle_managed_keys property of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type is_using_oracle_managed_keys: bool

        """
        self.swagger_types = {
            'kms_key_id': 'str',
            'vault_id': 'str',
            'is_using_oracle_managed_keys': 'bool'
        }

        self.attribute_map = {
            'kms_key_id': 'kmsKeyId',
            'vault_id': 'vaultId',
            'is_using_oracle_managed_keys': 'isUsingOracleManagedKeys'
        }

        self._kms_key_id = None
        self._vault_id = None
        self._is_using_oracle_managed_keys = None

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def vault_id(self):
        """
        Gets the vault_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The vault_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param vault_id: The vault_id of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def is_using_oracle_managed_keys(self):
        """
        Gets the is_using_oracle_managed_keys of this ConfigureAutonomousDatabaseVaultKeyDetails.
        True if disable Customer Managed Keys and use Oracle Managed Keys.


        :return: The is_using_oracle_managed_keys of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :rtype: bool
        """
        return self._is_using_oracle_managed_keys

    @is_using_oracle_managed_keys.setter
    def is_using_oracle_managed_keys(self, is_using_oracle_managed_keys):
        """
        Sets the is_using_oracle_managed_keys of this ConfigureAutonomousDatabaseVaultKeyDetails.
        True if disable Customer Managed Keys and use Oracle Managed Keys.


        :param is_using_oracle_managed_keys: The is_using_oracle_managed_keys of this ConfigureAutonomousDatabaseVaultKeyDetails.
        :type: bool
        """
        self._is_using_oracle_managed_keys = is_using_oracle_managed_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .compute_instance_group_failure_policy import ComputeInstanceGroupFailurePolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceGroupFailurePolicyByPercentage(ComputeInstanceGroupFailurePolicy):
    """
    Specifies a failure policy by percentage for a compute instance group rolling deployment stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceGroupFailurePolicyByPercentage object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.ComputeInstanceGroupFailurePolicyByPercentage.policy_type` attribute
        of this class is ``COMPUTE_INSTANCE_GROUP_FAILURE_POLICY_BY_PERCENTAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this ComputeInstanceGroupFailurePolicyByPercentage.
            Allowed values for this property are: "COMPUTE_INSTANCE_GROUP_FAILURE_POLICY_BY_COUNT", "COMPUTE_INSTANCE_GROUP_FAILURE_POLICY_BY_PERCENTAGE"
        :type policy_type: str

        :param failure_percentage:
            The value to assign to the failure_percentage property of this ComputeInstanceGroupFailurePolicyByPercentage.
        :type failure_percentage: int

        """
        self.swagger_types = {
            'policy_type': 'str',
            'failure_percentage': 'int'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'failure_percentage': 'failurePercentage'
        }

        self._policy_type = None
        self._failure_percentage = None
        self._policy_type = 'COMPUTE_INSTANCE_GROUP_FAILURE_POLICY_BY_PERCENTAGE'

    @property
    def failure_percentage(self):
        """
        **[Required]** Gets the failure_percentage of this ComputeInstanceGroupFailurePolicyByPercentage.
        The failure percentage threshold, which when reached or exceeded sets the stage as FAILED. Percentage is computed as the ceiling value of the number of failed instances over the total count of the instances in the group.


        :return: The failure_percentage of this ComputeInstanceGroupFailurePolicyByPercentage.
        :rtype: int
        """
        return self._failure_percentage

    @failure_percentage.setter
    def failure_percentage(self, failure_percentage):
        """
        Sets the failure_percentage of this ComputeInstanceGroupFailurePolicyByPercentage.
        The failure percentage threshold, which when reached or exceeded sets the stage as FAILED. Percentage is computed as the ceiling value of the number of failed instances over the total count of the instances in the group.


        :param failure_percentage: The failure_percentage of this ComputeInstanceGroupFailurePolicyByPercentage.
        :type: int
        """
        self._failure_percentage = failure_percentage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalePolicy(object):
    """
    Policy definitions for the autoscale configuration.
    """

    #: A constant which can be used with the policy_type property of a AutoScalePolicy.
    #: This constant has a value of "THRESHOLD_BASED"
    POLICY_TYPE_THRESHOLD_BASED = "THRESHOLD_BASED"

    #: A constant which can be used with the policy_type property of a AutoScalePolicy.
    #: This constant has a value of "SCHEDULE_BASED"
    POLICY_TYPE_SCHEDULE_BASED = "SCHEDULE_BASED"

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalePolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this AutoScalePolicy.
            Allowed values for this property are: "THRESHOLD_BASED", "SCHEDULE_BASED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type policy_type: str

        :param rules:
            The value to assign to the rules property of this AutoScalePolicy.
        :type rules: list[oci.bds.models.AutoScalePolicyRule]

        """
        self.swagger_types = {
            'policy_type': 'str',
            'rules': 'list[AutoScalePolicyRule]'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'rules': 'rules'
        }

        self._policy_type = None
        self._rules = None

    @property
    def policy_type(self):
        """
        **[Required]** Gets the policy_type of this AutoScalePolicy.
        Types of autoscale policies. Options are SCHEDULE-BASED or THRESHOLD-BASED. (Only THRESHOLD-BASED is supported in this release.)

        Allowed values for this property are: "THRESHOLD_BASED", "SCHEDULE_BASED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The policy_type of this AutoScalePolicy.
        :rtype: str
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """
        Sets the policy_type of this AutoScalePolicy.
        Types of autoscale policies. Options are SCHEDULE-BASED or THRESHOLD-BASED. (Only THRESHOLD-BASED is supported in this release.)


        :param policy_type: The policy_type of this AutoScalePolicy.
        :type: str
        """
        allowed_values = ["THRESHOLD_BASED", "SCHEDULE_BASED"]
        if not value_allowed_none_or_none_sentinel(policy_type, allowed_values):
            policy_type = 'UNKNOWN_ENUM_VALUE'
        self._policy_type = policy_type

    @property
    def rules(self):
        """
        **[Required]** Gets the rules of this AutoScalePolicy.
        The list of rules for autoscaling. If an action has multiple rules, the last rule in the array will be applied.


        :return: The rules of this AutoScalePolicy.
        :rtype: list[oci.bds.models.AutoScalePolicyRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this AutoScalePolicy.
        The list of rules for autoscaling. If an action has multiple rules, the last rule in the array will be applied.


        :param rules: The rules of this AutoScalePolicy.
        :type: list[oci.bds.models.AutoScalePolicyRule]
        """
        self._rules = rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalingConfiguration(object):
    """
    The information about the autoscale configuration.
    """

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AutoScalingConfiguration.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalingConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutoScalingConfiguration.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this AutoScalingConfiguration.
        :type display_name: str

        :param node_type:
            The value to assign to the node_type property of this AutoScalingConfiguration.
        :type node_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutoScalingConfiguration.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this AutoScalingConfiguration.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AutoScalingConfiguration.
        :type time_updated: datetime

        :param policy:
            The value to assign to the policy property of this AutoScalingConfiguration.
        :type policy: oci.bds.models.AutoScalePolicy

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'node_type': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'policy': 'AutoScalePolicy'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'node_type': 'nodeType',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'policy': 'policy'
        }

        self._id = None
        self._display_name = None
        self._node_type = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._policy = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutoScalingConfiguration.
        The unique identifier for the autoscale configuration.


        :return: The id of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutoScalingConfiguration.
        The unique identifier for the autoscale configuration.


        :param id: The id of this AutoScalingConfiguration.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AutoScalingConfiguration.
        A user-friendly name. The name does not have to be unique, and it may be changed. Avoid entering confidential information.


        :return: The display_name of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AutoScalingConfiguration.
        A user-friendly name. The name does not have to be unique, and it may be changed. Avoid entering confidential information.


        :param display_name: The display_name of this AutoScalingConfiguration.
        :type: str
        """
        self._display_name = display_name

    @property
    def node_type(self):
        """
        **[Required]** Gets the node_type of this AutoScalingConfiguration.
        A node type that is managed by an autoscale configuration. The only supported type is WORKER.


        :return: The node_type of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this AutoScalingConfiguration.
        A node type that is managed by an autoscale configuration. The only supported type is WORKER.


        :param node_type: The node_type of this AutoScalingConfiguration.
        :type: str
        """
        self._node_type = node_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AutoScalingConfiguration.
        The state of the autoscale configuration.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AutoScalingConfiguration.
        The state of the autoscale configuration.


        :param lifecycle_state: The lifecycle_state of this AutoScalingConfiguration.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AutoScalingConfiguration.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :return: The time_created of this AutoScalingConfiguration.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AutoScalingConfiguration.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :param time_created: The time_created of this AutoScalingConfiguration.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this AutoScalingConfiguration.
        The time the autoscale configuration was updated, shown as an RFC 3339 formatted datetime string.


        :return: The time_updated of this AutoScalingConfiguration.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AutoScalingConfiguration.
        The time the autoscale configuration was updated, shown as an RFC 3339 formatted datetime string.


        :param time_updated: The time_updated of this AutoScalingConfiguration.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def policy(self):
        """
        **[Required]** Gets the policy of this AutoScalingConfiguration.

        :return: The policy of this AutoScalingConfiguration.
        :rtype: oci.bds.models.AutoScalePolicy
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """
        Sets the policy of this AutoScalingConfiguration.

        :param policy: The policy of this AutoScalingConfiguration.
        :type: oci.bds.models.AutoScalePolicy
        """
        self._policy = policy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployStageExecutionStep(object):
    """
    Details about each steps in stage execution for a target environment.
    """

    #: A constant which can be used with the state property of a DeployStageExecutionStep.
    #: This constant has a value of "WAITING"
    STATE_WAITING = "WAITING"

    #: A constant which can be used with the state property of a DeployStageExecutionStep.
    #: This constant has a value of "IN_PROGRESS"
    STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the state property of a DeployStageExecutionStep.
    #: This constant has a value of "FAILED"
    STATE_FAILED = "FAILED"

    #: A constant which can be used with the state property of a DeployStageExecutionStep.
    #: This constant has a value of "SUCCEEDED"
    STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the state property of a DeployStageExecutionStep.
    #: This constant has a value of "CANCELED"
    STATE_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new DeployStageExecutionStep object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DeployStageExecutionStep.
        :type name: str

        :param state:
            The value to assign to the state property of this DeployStageExecutionStep.
            Allowed values for this property are: "WAITING", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        :param time_started:
            The value to assign to the time_started property of this DeployStageExecutionStep.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this DeployStageExecutionStep.
        :type time_finished: datetime

        """
        self.swagger_types = {
            'name': 'str',
            'state': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime'
        }

        self.attribute_map = {
            'name': 'name',
            'state': 'state',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished'
        }

        self._name = None
        self._state = None
        self._time_started = None
        self._time_finished = None

    @property
    def name(self):
        """
        Gets the name of this DeployStageExecutionStep.
        Name of the step.


        :return: The name of this DeployStageExecutionStep.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DeployStageExecutionStep.
        Name of the step.


        :param name: The name of this DeployStageExecutionStep.
        :type: str
        """
        self._name = name

    @property
    def state(self):
        """
        Gets the state of this DeployStageExecutionStep.
        State of the step.

        Allowed values for this property are: "WAITING", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this DeployStageExecutionStep.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this DeployStageExecutionStep.
        State of the step.


        :param state: The state of this DeployStageExecutionStep.
        :type: str
        """
        allowed_values = ["WAITING", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    @property
    def time_started(self):
        """
        Gets the time_started of this DeployStageExecutionStep.
        Time when the step started.


        :return: The time_started of this DeployStageExecutionStep.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this DeployStageExecutionStep.
        Time when the step started.


        :param time_started: The time_started of this DeployStageExecutionStep.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this DeployStageExecutionStep.
        Time when the step finished.


        :return: The time_finished of this DeployStageExecutionStep.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this DeployStageExecutionStep.
        Time when the step finished.


        :param time_finished: The time_finished of this DeployStageExecutionStep.
        :type: datetime
        """
        self._time_finished = time_finished

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchLogsDetails(object):
    """
    Search request object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchLogsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_start:
            The value to assign to the time_start property of this SearchLogsDetails.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this SearchLogsDetails.
        :type time_end: datetime

        :param search_query:
            The value to assign to the search_query property of this SearchLogsDetails.
        :type search_query: str

        :param is_return_field_info:
            The value to assign to the is_return_field_info property of this SearchLogsDetails.
        :type is_return_field_info: bool

        """
        self.swagger_types = {
            'time_start': 'datetime',
            'time_end': 'datetime',
            'search_query': 'str',
            'is_return_field_info': 'bool'
        }

        self.attribute_map = {
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'search_query': 'searchQuery',
            'is_return_field_info': 'isReturnFieldInfo'
        }

        self._time_start = None
        self._time_end = None
        self._search_query = None
        self._is_return_field_info = None

    @property
    def time_start(self):
        """
        **[Required]** Gets the time_start of this SearchLogsDetails.
        Start filter log's date and time, in the format defined by RFC3339.


        :return: The time_start of this SearchLogsDetails.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this SearchLogsDetails.
        Start filter log's date and time, in the format defined by RFC3339.


        :param time_start: The time_start of this SearchLogsDetails.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        **[Required]** Gets the time_end of this SearchLogsDetails.
        End filter log's date and time, in the format defined by RFC3339.


        :return: The time_end of this SearchLogsDetails.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this SearchLogsDetails.
        End filter log's date and time, in the format defined by RFC3339.


        :param time_end: The time_end of this SearchLogsDetails.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def search_query(self):
        """
        **[Required]** Gets the search_query of this SearchLogsDetails.
        Query corresponding to the search operation. This query is parsed and validated before execution and
        should follow the specification. For more information on the query language specification, see
        `Logging Query Language Specification`__.

        __ https://docs.cloud.oracle.com/Content/Logging/Reference/query_language_specification.htm


        :return: The search_query of this SearchLogsDetails.
        :rtype: str
        """
        return self._search_query

    @search_query.setter
    def search_query(self, search_query):
        """
        Sets the search_query of this SearchLogsDetails.
        Query corresponding to the search operation. This query is parsed and validated before execution and
        should follow the specification. For more information on the query language specification, see
        `Logging Query Language Specification`__.

        __ https://docs.cloud.oracle.com/Content/Logging/Reference/query_language_specification.htm


        :param search_query: The search_query of this SearchLogsDetails.
        :type: str
        """
        self._search_query = search_query

    @property
    def is_return_field_info(self):
        """
        Gets the is_return_field_info of this SearchLogsDetails.
        Whether to return field schema information for the log stream specified in searchQuery.


        :return: The is_return_field_info of this SearchLogsDetails.
        :rtype: bool
        """
        return self._is_return_field_info

    @is_return_field_info.setter
    def is_return_field_info(self, is_return_field_info):
        """
        Sets the is_return_field_info of this SearchLogsDetails.
        Whether to return field schema information for the log stream specified in searchQuery.


        :param is_return_field_info: The is_return_field_info of this SearchLogsDetails.
        :type: bool
        """
        self._is_return_field_info = is_return_field_info

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Script(object):
    """
    The information about the script.
    """

    #: A constant which can be used with the content_type property of a Script.
    #: This constant has a value of "SIDE"
    CONTENT_TYPE_SIDE = "SIDE"

    #: A constant which can be used with the content_type property of a Script.
    #: This constant has a value of "JS"
    CONTENT_TYPE_JS = "JS"

    def __init__(self, **kwargs):
        """
        Initializes a new Script object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Script.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Script.
        :type display_name: str

        :param content_type:
            The value to assign to the content_type property of this Script.
            Allowed values for this property are: "SIDE", "JS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type content_type: str

        :param content:
            The value to assign to the content property of this Script.
        :type content: str

        :param time_uploaded:
            The value to assign to the time_uploaded property of this Script.
        :type time_uploaded: datetime

        :param content_size_in_bytes:
            The value to assign to the content_size_in_bytes property of this Script.
        :type content_size_in_bytes: int

        :param content_file_name:
            The value to assign to the content_file_name property of this Script.
        :type content_file_name: str

        :param parameters:
            The value to assign to the parameters property of this Script.
        :type parameters: list[oci.apm_synthetics.models.ScriptParameterInfo]

        :param monitor_status_count_map:
            The value to assign to the monitor_status_count_map property of this Script.
        :type monitor_status_count_map: oci.apm_synthetics.models.MonitorStatusCountMap

        :param time_created:
            The value to assign to the time_created property of this Script.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Script.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Script.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Script.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'content_type': 'str',
            'content': 'str',
            'time_uploaded': 'datetime',
            'content_size_in_bytes': 'int',
            'content_file_name': 'str',
            'parameters': 'list[ScriptParameterInfo]',
            'monitor_status_count_map': 'MonitorStatusCountMap',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'content_type': 'contentType',
            'content': 'content',
            'time_uploaded': 'timeUploaded',
            'content_size_in_bytes': 'contentSizeInBytes',
            'content_file_name': 'contentFileName',
            'parameters': 'parameters',
            'monitor_status_count_map': 'monitorStatusCountMap',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._content_type = None
        self._content = None
        self._time_uploaded = None
        self._content_size_in_bytes = None
        self._content_file_name = None
        self._parameters = None
        self._monitor_status_count_map = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Script.
        The `OCID`__ of the script.
        scriptId is mandatory for creation of SCRIPTED_BROWSER and SCRIPTED_REST monitor types. For other monitor types, it should be set to null.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this Script.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Script.
        The `OCID`__ of the script.
        scriptId is mandatory for creation of SCRIPTED_BROWSER and SCRIPTED_REST monitor types. For other monitor types, it should be set to null.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this Script.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Script.
        Unique name that can be edited. The name should not contain any confidential information.


        :return: The display_name of this Script.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Script.
        Unique name that can be edited. The name should not contain any confidential information.


        :param display_name: The display_name of this Script.
        :type: str
        """
        self._display_name = display_name

    @property
    def content_type(self):
        """
        **[Required]** Gets the content_type of this Script.
        Content type of the script.

        Allowed values for this property are: "SIDE", "JS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The content_type of this Script.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this Script.
        Content type of the script.


        :param content_type: The content_type of this Script.
        :type: str
        """
        allowed_values = ["SIDE", "JS"]
        if not value_allowed_none_or_none_sentinel(content_type, allowed_values):
            content_type = 'UNKNOWN_ENUM_VALUE'
        self._content_type = content_type

    @property
    def content(self):
        """
        Gets the content of this Script.
        The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters.
        The format to set dynamic parameters is: `<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`.
        Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false.
        Examples:
        With mandatory param name : `<ORAP><ON>param name</ON></ORAP>`
        With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>`
        Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.


        :return: The content of this Script.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this Script.
        The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters.
        The format to set dynamic parameters is: `<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`.
        Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false.
        Examples:
        With mandatory param name : `<ORAP><ON>param name</ON></ORAP>`
        With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>`
        Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.


        :param content: The content of this Script.
        :type: str
        """
        self._content = content

    @property
    def time_uploaded(self):
        """
        Gets the time_uploaded of this Script.
        The time when the script was uploaded.


        :return: The time_uploaded of this Script.
        :rtype: datetime
        """
        return self._time_uploaded

    @time_uploaded.setter
    def time_uploaded(self, time_uploaded):
        """
        Sets the time_uploaded of this Script.
        The time when the script was uploaded.


        :param time_uploaded: The time_uploaded of this Script.
        :type: datetime
        """
        self._time_uploaded = time_uploaded

    @property
    def content_size_in_bytes(self):
        """
        Gets the content_size_in_bytes of this Script.
        Size of the script content.


        :return: The content_size_in_bytes of this Script.
        :rtype: int
        """
        return self._content_size_in_bytes

    @content_size_in_bytes.setter
    def content_size_in_bytes(self, content_size_in_bytes):
        """
        Sets the content_size_in_bytes of this Script.
        Size of the script content.


        :param content_size_in_bytes: The content_size_in_bytes of this Script.
        :type: int
        """
        self._content_size_in_bytes = content_size_in_bytes

    @property
    def content_file_name(self):
        """
        Gets the content_file_name of this Script.
        File name of the uploaded script content.


        :return: The content_file_name of this Script.
        :rtype: str
        """
        return self._content_file_name

    @content_file_name.setter
    def content_file_name(self, content_file_name):
        """
        Sets the content_file_name of this Script.
        File name of the uploaded script content.


        :param content_file_name: The content_file_name of this Script.
        :type: str
        """
        self._content_file_name = content_file_name

    @property
    def parameters(self):
        """
        Gets the parameters of this Script.
        List of script parameters. Example: `[{\"scriptParameter\": {\"paramName\": \"userid\", \"paramValue\":\"testuser\", \"isSecret\": false}, \"isOverwritten\": false}]`


        :return: The parameters of this Script.
        :rtype: list[oci.apm_synthetics.models.ScriptParameterInfo]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this Script.
        List of script parameters. Example: `[{\"scriptParameter\": {\"paramName\": \"userid\", \"paramValue\":\"testuser\", \"isSecret\": false}, \"isOverwritten\": false}]`


        :param parameters: The parameters of this Script.
        :type: list[oci.apm_synthetics.models.ScriptParameterInfo]
        """
        self._parameters = parameters

    @property
    def monitor_status_count_map(self):
        """
        **[Required]** Gets the monitor_status_count_map of this Script.

        :return: The monitor_status_count_map of this Script.
        :rtype: oci.apm_synthetics.models.MonitorStatusCountMap
        """
        return self._monitor_status_count_map

    @monitor_status_count_map.setter
    def monitor_status_count_map(self, monitor_status_count_map):
        """
        Sets the monitor_status_count_map of this Script.

        :param monitor_status_count_map: The monitor_status_count_map of this Script.
        :type: oci.apm_synthetics.models.MonitorStatusCountMap
        """
        self._monitor_status_count_map = monitor_status_count_map

    @property
    def time_created(self):
        """
        Gets the time_created of this Script.
        The time the resource was created, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Script.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Script.
        The time the resource was created, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Script.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Script.
        The time the resource was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Script.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Script.
        The time the resource was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Script.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Script.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Script.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Script.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Script.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Script.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Script.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Script.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Script.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CompleteExternalBackupJobDetails(object):
    """
    CompleteExternalBackupJobDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CompleteExternalBackupJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tde_wallet_path:
            The value to assign to the tde_wallet_path property of this CompleteExternalBackupJobDetails.
        :type tde_wallet_path: str

        :param cf_backup_handle:
            The value to assign to the cf_backup_handle property of this CompleteExternalBackupJobDetails.
        :type cf_backup_handle: str

        :param spf_backup_handle:
            The value to assign to the spf_backup_handle property of this CompleteExternalBackupJobDetails.
        :type spf_backup_handle: str

        :param sql_patches:
            The value to assign to the sql_patches property of this CompleteExternalBackupJobDetails.
        :type sql_patches: list[str]

        :param data_size:
            The value to assign to the data_size property of this CompleteExternalBackupJobDetails.
        :type data_size: int

        :param redo_size:
            The value to assign to the redo_size property of this CompleteExternalBackupJobDetails.
        :type redo_size: int

        """
        self.swagger_types = {
            'tde_wallet_path': 'str',
            'cf_backup_handle': 'str',
            'spf_backup_handle': 'str',
            'sql_patches': 'list[str]',
            'data_size': 'int',
            'redo_size': 'int'
        }

        self.attribute_map = {
            'tde_wallet_path': 'tdeWalletPath',
            'cf_backup_handle': 'cfBackupHandle',
            'spf_backup_handle': 'spfBackupHandle',
            'sql_patches': 'sqlPatches',
            'data_size': 'dataSize',
            'redo_size': 'redoSize'
        }

        self._tde_wallet_path = None
        self._cf_backup_handle = None
        self._spf_backup_handle = None
        self._sql_patches = None
        self._data_size = None
        self._redo_size = None

    @property
    def tde_wallet_path(self):
        """
        Gets the tde_wallet_path of this CompleteExternalBackupJobDetails.
        If the database being backed up is TDE enabled, this will be the path to the associated TDE wallet in Object Storage.


        :return: The tde_wallet_path of this CompleteExternalBackupJobDetails.
        :rtype: str
        """
        return self._tde_wallet_path

    @tde_wallet_path.setter
    def tde_wallet_path(self, tde_wallet_path):
        """
        Sets the tde_wallet_path of this CompleteExternalBackupJobDetails.
        If the database being backed up is TDE enabled, this will be the path to the associated TDE wallet in Object Storage.


        :param tde_wallet_path: The tde_wallet_path of this CompleteExternalBackupJobDetails.
        :type: str
        """
        self._tde_wallet_path = tde_wallet_path

    @property
    def cf_backup_handle(self):
        """
        Gets the cf_backup_handle of this CompleteExternalBackupJobDetails.
        The handle of the control file backup.


        :return: The cf_backup_handle of this CompleteExternalBackupJobDetails.
        :rtype: str
        """
        return self._cf_backup_handle

    @cf_backup_handle.setter
    def cf_backup_handle(self, cf_backup_handle):
        """
        Sets the cf_backup_handle of this CompleteExternalBackupJobDetails.
        The handle of the control file backup.


        :param cf_backup_handle: The cf_backup_handle of this CompleteExternalBackupJobDetails.
        :type: str
        """
        self._cf_backup_handle = cf_backup_handle

    @property
    def spf_backup_handle(self):
        """
        Gets the spf_backup_handle of this CompleteExternalBackupJobDetails.
        The handle of the spfile backup.


        :return: The spf_backup_handle of this CompleteExternalBackupJobDetails.
        :rtype: str
        """
        return self._spf_backup_handle

    @spf_backup_handle.setter
    def spf_backup_handle(self, spf_backup_handle):
        """
        Sets the spf_backup_handle of this CompleteExternalBackupJobDetails.
        The handle of the spfile backup.


        :param spf_backup_handle: The spf_backup_handle of this CompleteExternalBackupJobDetails.
        :type: str
        """
        self._spf_backup_handle = spf_backup_handle

    @property
    def sql_patches(self):
        """
        Gets the sql_patches of this CompleteExternalBackupJobDetails.
        The list of SQL patches that need to be applied to the backup during the restore.


        :return: The sql_patches of this CompleteExternalBackupJobDetails.
        :rtype: list[str]
        """
        return self._sql_patches

    @sql_patches.setter
    def sql_patches(self, sql_patches):
        """
        Sets the sql_patches of this CompleteExternalBackupJobDetails.
        The list of SQL patches that need to be applied to the backup during the restore.


        :param sql_patches: The sql_patches of this CompleteExternalBackupJobDetails.
        :type: list[str]
        """
        self._sql_patches = sql_patches

    @property
    def data_size(self):
        """
        Gets the data_size of this CompleteExternalBackupJobDetails.
        The size of the data in the database, in megabytes.


        :return: The data_size of this CompleteExternalBackupJobDetails.
        :rtype: int
        """
        return self._data_size

    @data_size.setter
    def data_size(self, data_size):
        """
        Sets the data_size of this CompleteExternalBackupJobDetails.
        The size of the data in the database, in megabytes.


        :param data_size: The data_size of this CompleteExternalBackupJobDetails.
        :type: int
        """
        self._data_size = data_size

    @property
    def redo_size(self):
        """
        Gets the redo_size of this CompleteExternalBackupJobDetails.
        The size of the redo in the database, in megabytes.


        :return: The redo_size of this CompleteExternalBackupJobDetails.
        :rtype: int
        """
        return self._redo_size

    @redo_size.setter
    def redo_size(self, redo_size):
        """
        Sets the redo_size of this CompleteExternalBackupJobDetails.
        The size of the redo in the database, in megabytes.


        :param redo_size: The redo_size of this CompleteExternalBackupJobDetails.
        :type: int
        """
        self._redo_size = redo_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
